import json

from flask import Blueprint, jsonify, Response

from inventory_provider.routes import common

routes = Blueprint("msr-query-routes", __name__)


@routes.after_request
def after_request(resp):
    return common.after_request(resp)


@routes.route("/access-services", methods=['GET', 'POST'])
@common.require_accepts_json
def access_services():

    redis = common.get_current_redis()

    def _services():
        for k in redis.scan_iter('opsdb:access_services:*'):
            service = redis.get(k.decode('utf-8')).decode('utf-8')
            yield json.loads(service)

    cache_key = 'classifier-cache:msr:access-services'
    result = redis.get(cache_key)

    if result:
        result = json.loads(result.decode('utf-8'))
    else:
        result = list(_services())
        # cache this data for the next call
        redis.set(cache_key, json.dumps(result).encode('utf-8'))

    if not result:
        return Response(
            response='no access services found',
            status=404,
            mimetype="text/html")

    return jsonify(result)
